<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

if ( ! function_exists( 'sociable_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Sociable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sociable_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'sociable_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'sociable_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Sociable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sociable_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'sociable_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'sociable_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Sociable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function sociable_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'sociable_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_topbar_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design', 'third-design', 'second-design', 'fourth-design','fifth-design', 'sixth-design'));
}

/**
 * Check if topbar section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[topbar_section_enable]' )->value() );
}


/**
 * Check if Indroduction  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_introduction_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design','third-design'));
}

/**
 * Check if introduction section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_introduction_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[introduction_section_enable]' )->value() );
}

/**
 * Check if introduction section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_introduction_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[introduction_content_type]' )->value();
	return sociable_pro_is_introduction_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if introduction section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_introduction_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[introduction_content_type]' )->value();
	return sociable_pro_is_introduction_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if introduction section content type is custom.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_introduction_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[introduction_content_type]' )->value();
	return sociable_pro_is_introduction_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if clients section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_clients_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[clients_section_enable]' )->value() );
}

/**
 * Check if clients section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_clients_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[clients_content_type]' )->value();
	return sociable_pro_is_clients_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if clients section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_clients_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[clients_content_type]' )->value();
	return sociable_pro_is_clients_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if clients section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_clients_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[clients_content_type]' )->value();
	return sociable_pro_is_clients_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if clients section content type is custom.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_clients_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[clients_content_type]' )->value();
	return sociable_pro_is_clients_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if portfolio section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_portfolio_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[portfolio_section_enable]' )->value() );
}

/**
 * Check if portfolio section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_portfolio_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[portfolio_content_type]' )->value();
	return sociable_pro_is_portfolio_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if portfolio section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_portfolio_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[portfolio_content_type]' )->value();
	return sociable_pro_is_portfolio_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if portfolio section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_portfolio_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[portfolio_content_type]' )->value();
	return sociable_pro_is_portfolio_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if youtube design is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_youtube_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design','third-design'));
}

/**
 * Check if Client  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_client_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design','fifth-design'));
}
/**
 * Check if Blog  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_instagram_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design'));
}

/**
 * Check if instagram section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_instagram_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[instagram_section_enable]' )->value() );
}

/**
 * Check if youtube section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_youtube_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[youtube_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[blog_content_type]' )->value();
	return sociable_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[blog_content_type]' )->value();
	return sociable_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[blog_content_type]' )->value();
	return sociable_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[blog_content_type]' )->value();
	return sociable_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if Blog  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_blog_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return ( in_array( $content_type , array( 'third-design', 'default-design' ) ) );
}

/**
 * Check if blog section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[popular_content_type]' )->value();
	return sociable_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[popular_content_type]' )->value();
	return sociable_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[popular_content_type]' )->value();
	return sociable_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is recent.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_popular_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[popular_content_type]' )->value();
	return sociable_pro_is_popular_section_enable( $control ) && ( 'recent' == $content_type );
}

/* Business Design*/

/**
 * Check if slider  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_slider_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fourth-design','fifth-design', 'sixth-design', 'default-design'));
}

/**
 * Check if slider section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[slider_content_type]' )->value();
	return sociable_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[slider_content_type]' )->value();
	return sociable_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[slider_content_type]' )->value();
	return sociable_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fourth-design','fifth-design', 'default-design'));
}

/**
 * Check if service section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[service_content_type]' )->value();
	return sociable_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[service_content_type]' )->value();
	return sociable_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[service_content_type]' )->value();
	return sociable_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[service_content_type]' )->value();
	return sociable_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}



/**************** About Section*******************/



/**
 * Check if about  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_about_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fourth-design','fifth-design', 'sixth-design', 'default-design'));
}

/**
 * Check if about section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[about_content_type]' )->value();
	return sociable_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[about_content_type]' )->value();
	return sociable_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[about_content_type]' )->value();
	return sociable_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==============Counter Section ==========================*/

/**
 * Check if counter  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_counter_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fourth-design','fifth-design', 'default-design'));
}

/**
 * Check if counter section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[counter_section_enable]' )->value() );
}

/*==============Team Section ==========================*/

/**
 * Check if team  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fourth-design','fifth-design', 'default-design'));
}

/**
 * Check if team section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[team_content_type]' )->value();
	return sociable_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[team_content_type]' )->value();
	return sociable_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[team_content_type]' )->value();
	return sociable_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[team_content_type]' )->value();
	return sociable_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[team_content_type]' )->value();
	return sociable_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}



/**
 * Check if features  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return ( in_array( $home_layout , array( 'fifth-design', 'default-design' ) ) );
}

/**
 * Check if features section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[features_section_enable]' )->value() );
}

/**
 * Check if features section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[features_content_type]' )->value();
	return sociable_pro_is_features_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if features section seperator.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[features_content_type]' )->value();
	return sociable_pro_is_features_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if features section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[features_content_type]' )->value();
	return sociable_pro_is_features_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if features section content type is category.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[features_content_type]' )->value();
	return sociable_pro_is_features_section_enable( $control ) && ( 'category' == $content_type );
}

/**************** Reason Section*******************/



/**
 * Check if reason  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_reason_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return ( in_array( $home_layout , array( 'fifth-design', 'default-design' ) ) );
}

/**
 * Check if reason section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is post.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[reason_content_type]' )->value();
	return sociable_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[reason_content_type]' )->value();
	return sociable_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[reason_content_type]' )->value();
	return sociable_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if reason  design section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_subscription_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return ( in_array( $home_layout, array( 'fourth-design', 'sixth-design', 'default-design' )  )  );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[subscription_section_enable]' )->value() );
}



/**
 * Check if featured_product section is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_featured_product_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','sixth-design'));
}

function sociable_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[featured_product_section_enable]' )->value() );
}

/**
 * Check if recent_product section is enabled.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_recent_product_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','sixth-design'));
}

function sociable_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[recent_product_section_enable]' )->value() );
}

function sociable_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[recent_product_content_type]' )->value();
	return sociable_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

function sociable_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[recent_product_content_type]' )->value();
	return sociable_pro_is_recent_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if latest_product section is enabled.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_latest_product_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','sixth-design'));
}

function sociable_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[latest_product_section_enable]' )->value() );
}

function sociable_pro_is_latest_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[latest_product_content_type]' )->value();
	return sociable_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

function sociable_pro_is_latest_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[latest_product_content_type]' )->value();
	return sociable_pro_is_latest_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function sociable_pro_is_cta_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'sociable_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','sixth-design'));
}

function sociable_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'sociable_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[cta_content_type]' )->value();
	return sociable_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[cta_content_type]' )->value();
	return sociable_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function sociable_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'sociable_pro_theme_options[cta_content_type]' )->value();
	return sociable_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}